% Figure1_6.m
% It requires the following functions:
% heun2(.m
% trapezoidal2.m
% spTVT2.m
% fKepler.m
% fKeplerT.m
% fKeplerV.m
% phiKepler
%
% midpoint2.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial and final time, and  Time step
global h
t0=0;  tf=200;   N=1*5000;  N2=N/2; t=[];
h = (tf-t0)/N;
% Initial Conditions 
e=0.2;   x0 = [1-e ; 0; 0; sqrt((1+e)/(1-e))];
q0=[x0(1); x0(2)];  p0=[x0(3); x0(4)]; 
% Energy at initial conditions
H0=((x0(3))^2+(x0(4))^2)/2-1/(sqrt((x0(1))^2+(x0(2))^2));

[t2 x2]=heun2(@fKepler,t0,tf,x0,N);
[t2 xt2]=trapezoidal2(@fKepler,t0,tf,x0,N);
[t q2 p2]=spTVT2(@fKeplerT,@fKeplerV,t0,tf,q0,p0,N);
[t q2m p2m]=spTVT2m(@fKeplerT,@fKeplerVm,t0,tf,q0,p0,N);
%[t2 xm2]=midpoint2(@fKepler,t0,tf,x0,N2);

 x = x0';th=t0;
q0(1)=x0(1);p0(1)=x0(2);q0(2)=x0(3);p0(2)=x0(4);
for i=1:N;
   th=th+h;
   [q p]=phiKepler(q0,p0,h);
   x=[x; q p];
   q0=q;p0=p;
end

eP=sqrt((x(:,1)-x2(:,1)).^2+(x(:,2)-x2(:,2)).^2+(x(:,3)-x2(:,3)).^2+(x(:,4)-x2(:,4)).^2);
ePT=sqrt((x(:,1)-xt2(:,1)).^2+(x(:,2)-xt2(:,2)).^2+(x(:,3)-xt2(:,3)).^2+(x(:,4)-xt2(:,4)).^2);
eSVT=sqrt((x(:,1)-q2(:,1)).^2+(x(:,2)-q2(:,2)).^2+(x(:,3)-p2(:,1)).^2+(x(:,4)-p2(:,2)).^2);
eSVTm=sqrt((x(:,1)-q2m(:,1)).^2+(x(:,2)-q2m(:,2)).^2+(x(:,3)-p2m(:,1)).^2+(x(:,4)-p2m(:,2)).^2);
%eSTV=sqrt((x(:,1)-q1(:,1)).^2+(x(:,2)-q1(:,2)).^2+(x(:,3)-p1(:,1)).^2+(x(:,4)-p1(:,2)).^2);

errorSVT = ((p2(:,1)).^2+(p2(:,2)).^2)./2-1./(sqrt((q2(:,1)).^2+(q2(:,2)).^2)) - H0;
errorSVTm = ((p2m(:,1)).^2+(p2m(:,2)).^2)./2-1./(sqrt((q2m(:,1)).^2+(q2m(:,2)).^2)) - H0;
errorH2 = ((x2(:,3)).^2+(x2(:,4)).^2)./2-1./(sqrt((x2(:,1)).^2+(x2(:,2)).^2)) - H0;
errorT2 = ((xt2(:,3)).^2+(xt2(:,4)).^2)./2-1./(sqrt((xt2(:,1)).^2+(xt2(:,2)).^2)) - H0;
%errorM2 = ((xm2(:,3)).^2+(xm2(:,4)).^2)./2-1./(sqrt((xm2(:,1)).^2+(xm2(:,2)).^2)) - H0;

figure(1)
 subplot(2,2,1)
  hold on
  plot(t2,errorH2(:),':k','LineWidth',1.5,'Color',[0 0 0]+0.7)
  plot(t2,errorT2(:),'-k','LineWidth',1.5,'Color',[0 0 0]+0.9)
  plot(t,errorSVT(:),'k--','LineWidth',1.5,'Color',[0 0 0]+0.0)
  plot(t,errorSVTm(:),'k-','LineWidth',1.5,'Color',[0 0 0]+0)
% plot(t2,errorM2(:),'--b','MarkerSize',8,'LineWidth',3)
  axis([-1 200 -0.0005 0.0025]) 
  xlabel('{\fontsize{14} t }')   
  ylabel('{\fontsize{14} H(t)-H_0}')   
  box

 subplot(2,2,2)
  hold on
  plot(log10(t),log10(abs(errorH2(:))),':k','LineWidth',1.5,'Color',[0 0 0]+0.7)
  plot(log10(t),log10(abs(errorT2(:))),'-k','LineWidth',1.5,'Color',[0 0 0]+0.9)
  plot(log10(t),log10(abs(errorSVT(:))),'k--','LineWidth',1.5,'Color',[0 0 0]+0.0)
  plot(log10(t),log10(abs(errorSVTm(:))),'k-','LineWidth',1.5,'Color',[0 0 0]+0)
  axis([-1 2.3 -5 -2]) 
  xlabel('{\fontsize{14} log_{10}(t) }')   
  ylabel('{\fontsize{14} log_{10}|H(t)-H_0|}')   
  box


 subplot(2,2,3)
  hold on
  plot(t,eP,':k','MarkerSize',8,'LineWidth',1.5,'Color',[0 0 0]+0.7)
  plot(t,ePT,'-k','MarkerSize',8,'LineWidth',1.5,'Color',[0 0 0]+0.9)
  plot(t,eSVT,'--k','MarkerSize',8,'LineWidth',1.5,'Color',[0 0 0]+0.0)
  plot(t,eSVTm,'-k','MarkerSize',8,'LineWidth',1.5,'Color',[0 0 0]+0)
  axis([-1 200 -0.05 2.5]) 
  xlabel('{\fontsize{14} t }')   
  ylabel('{\fontsize{14} err(q,p)}')   
  box

 subplot(2,2,4)
  hold on
  plot(log10(t),log10(eP),':k','MarkerSize',8,'LineWidth',1.5,'Color',[0 0 0]+0.7)
  plot(log10(t),log10(ePT),'-k','MarkerSize',8,'LineWidth',1.5,'Color',[0 0 0]+0.9)
  plot(log10(t),log10(eSVT),'--k','MarkerSize',8,'LineWidth',1.5,'Color',[0 0 0]+0.0)
  plot(log10(t),log10(eSVTm),'-k','MarkerSize',8,'LineWidth',1.5,'Color',[0 0 0]+0)
  axis([-1 2.3 -4.5 0.5]) 
  xlabel('{\fontsize{14} log_{10}(t) }')   
  ylabel('{\fontsize{14} log_{10}(err(q,p))}')   
  box
